# -*- coding: utf-8 -*-
# #############################################################################
#  ATTENTION
# #############################################################################
#
#  This software is for guidance only. It is provided "as is".
#  It only aims at providing coding information to the customer in order for
#  them to save time. As a result no warranties, whether express, implied or
#  statutory, including, but not limited to implied warranties of
#  merchantability and fitness for a particular purpose apply to this software.
#  A·P·E Angewandte Physik und Elektronik GmbH shall not be held liable for any
#  direct, indirect or consequential damages with respect to any claims arising
#  from the content of such sourcecode and/or the use made by customers of the
#  coding information contained herein in connection with their products.
#
#  File Version: 1.0
#
#  Changelog:
#    1.0 - Initial Version
#
# #############################################################################

import ape_device
import numpy as np
import matplotlib.pylab as p
from time import sleep

#Open TCP connection to the device using the APE Device class
#Change IP-Address and Portnumber according to your setup!
waveScan = ape_device.ape_device(host="127.0.0.1", port=51123)

#Read device identification
print("IDN: "+waveScan.idn())

#Read ACF data (make sure, that the device is running to get valid results)
spectrum_binary_data = bytes(waveScan.query("spectrum:data?", True))

#Unpack binary data into an array of float64/Double values.
#Values on even array-indices are the wavelength values, values on odd array-indices are the intensity values.
spectrum = np.fromstring(spectrum_binary_data,dtype=np.float64)

#Plot the Spectrum
p.figure()
p.plot(spectrum[0::2], spectrum[1::2])
p.title('waveScan USB - Spectrum')
p.xlabel('Wavelength [nm]')
p.ylabel('Intensity [arb.u.]')
p.show()

#Close the TCP connection
waveScan.disconnect()